@@ -23,7 +23,6 @@ from googlecloudsdk.api_lib.util import apis
 from googlecloudsdk.api_lib.util import messages as messages_util
 from googlecloudsdk.command_lib.ai import constants
 from googlecloudsdk.command_lib.ai import validation
-from googlecloudsdk.core import log
 from googlecloudsdk.core import yaml
 
 
@@ -47,8 +46,29 @@ class CustomJobsClient(object):
              specs=None,
              config_path=None,
              display_name=None,
-             python_package_uri=None):
-    """Constructs a request and sends it to the endpoint to create a custom job instance."""
+             python_package_uri=None,
+             args=None,
+             command=None,
+             kms_key_name=None):
+    """Constructs a request and sends it to the endpoint to create a custom job instance.
+
+    Args:
+      parent: str, The proje resource path of the custom job to create.
+      specs: ArgDict, A dictionary of worker pool specification for the custom
+        job to create.
+      config_path: str, Local path of a yaml file which contains the worker pool
+        specification.
+      display_name: str, The display name of the custom job to create.
+      python_package_uri: str, The common python package uris that will be used
+        by python image.
+      args: ArgList, A list of argument that passed to containers or python
+        packge.
+      command: ArgList, A list of command that passed to containers.
+      kms_key_name: A customer-managed encryption key to use for the custom job.
+
+    Returns:
+      (GoogleCloudAiplatformV1alpha1CustomJob) The created custom job.
+    """
     if not python_package_uri:
       python_package_uri = []
 
@@ -81,15 +101,20 @@ class CustomJobsClient(object):
           worker_pool_spec.containerSpec = (
               self.messages.GoogleCloudAiplatformV1beta1ContainerSpec(
                   imageUri=container_image_uri))
+          if args is not None:
+            worker_pool_spec.containerSpec.args = args
+          if command is not None:
+            worker_pool_spec.containerSpec.command = command
 
-        # TODO(b/161753810): Pass args and commands to the python package
-        # and container.
         if python_package_uri or python_image_uri or python_module:
           worker_pool_spec.pythonPackageSpec = (
               self.messages.GoogleCloudAiplatformV1beta1PythonPackageSpec(
                   executorImageUri=python_image_uri,
                   packageUris=python_package_uri,
                   pythonModule=python_module))
+          if args is not None:
+            worker_pool_spec.pythonPackageSpec.args = args
+
         worker_pool_specs.append(worker_pool_spec)
 
     if worker_pool_specs:
@@ -98,7 +123,11 @@ class CustomJobsClient(object):
 
     custom_job = (
         self.messages.GoogleCloudAiplatformV1beta1CustomJob(
-            displayName=display_name, jobSpec=job_spec))
+            displayName=display_name,
+            jobSpec=job_spec))
+    if kms_key_name is not None:
+      custom_job.encryptionSpec = self.messages.GoogleCloudAiplatformV1beta1EncryptionSpec(
+          kmsKeyName=kms_key_name)
 
     return self._service.Create(
         self.messages.AiplatformProjectsLocationsCustomJobsCreateRequest(
@@ -135,7 +164,6 @@ class CustomJobsClient(object):
     request = self.messages.AiplatformProjectsLocationsCustomJobsGetRequest(
         name=name)
     response = self._service.Get(request)
-    log.status.Print(response.endTime is None)
 
     def ShouldContinue(periods_without_logs):
       if periods_without_logs <= 1:
