@@ -48,7 +48,8 @@ class HpTuningJobsClient(object):
              parent=None,
              max_trial_count=None,
              parallel_trial_count=None,
-             algorithm=None):
+             algorithm=None,
+             kms_key_name=None):
     """Creates a hyperparameter tuning job with given parameters.
 
     Args:
@@ -64,6 +65,8 @@ class HpTuningJobsClient(object):
         parallel. The default value is 1.
       algorithm: AlgorithmValueValuesEnum, the search algorithm specified for
         the Study.
+      kms_key_name: A customer-managed encryption key to use for the
+        hyperparameter tuning job.
 
     Returns:
       Created hyperparameter tuning job.
@@ -87,6 +90,10 @@ class HpTuningJobsClient(object):
     if algorithm and job_spec.studySpec:
       job_spec.studySpec.algorithm = algorithm
 
+    if kms_key_name is not None:
+      job_spec.encryptionSpec = self.messages.GoogleCloudAiplatformV1beta1EncryptionSpec(
+          kmsKeyName=kms_key_name)
+
     return self._service.Create(
         self.messages
         .AiplatformProjectsLocationsHyperparameterTuningJobsCreateRequest(
@@ -112,3 +119,23 @@ class HpTuningJobsClient(object):
         field='hyperparameterTuningJobs',
         batch_size_attribute='pageSize',
         limit=limit)
+
+  def CheckJobComplete(self, name):
+    """Returns a function to decide if log fetcher should continue polling.
+
+    Args:
+      name: String id of job.
+
+    Returns:
+      A one-argument function decides if log fetcher should continue.
+    """
+    request = self.messages.AiplatformProjectsLocationsHyperparameterTuningJobsGetRequest(
+        name=name)
+    response = self._service.Get(request)
+
+    def ShouldContinue(periods_without_logs):
+      if periods_without_logs <= 1:
+        return True
+      return response.endTime is None
+
+    return ShouldContinue
