@@ -21,12 +21,14 @@ from __future__ import unicode_literals
 from googlecloudsdk.api_lib.resourcesettings import service as settings_service
 
 
-def GetCreateRequestFromArgs(args, setting_value):
+def GetCreateRequestFromArgs(args, parent_resource, setting_id, setting_value):
   """Returns the get_request from the user-specified arguments.
 
   Args:
     args: argparse.Namespace, An object that contains the values for the
       arguments specified in the Args method.
+    parent_resource: resource location such as `organizations/123`
+    setting_id: setting id such as `iam-projectCreatorRoles`
     setting_value: setting value object contains name, value and (optional) etag
   """
 
@@ -39,13 +41,38 @@ def GetCreateRequestFromArgs(args, setting_value):
   else:
     message_type = messages.ResourcesettingsProjectsSettingsValueCreateRequest
 
-  get_request = message_type(name=setting_value.name,
-                             googleCloudResourcesettingsV1alpha1SettingValue
+  get_request = message_type(parent=parent_resource,
+                             settingsId=setting_id,
+                             googleCloudResourcesettingsV1SettingValue
                              =setting_value)
 
   return get_request
 
 
+def GetDeleteValueRequestFromArgs(args, setting_name):
+  """Returns the get_request from the user-specified arguments.
+
+  Args:
+    args: argparse.Namespace, An object that contains the values for the
+      arguments specified in the Args method.
+    setting_name: setting name such as `settings/iam-projectCreatorRoles`
+  """
+
+  messages = settings_service.ResourceSettingsMessages()
+
+  if args.organization:
+    get_request = messages.ResourcesettingsOrganizationsSettingsDeleteValueRequest(
+        name=setting_name)
+  elif args.folder:
+    get_request = messages.ResourcesettingsFoldersSettingsDeleteValueRequest(
+        name=setting_name)
+  else:
+    get_request = messages.ResourcesettingsProjectsSettingsDeleteValueRequest(
+        name=setting_name)
+
+  return get_request
+
+
 def GetGetValueRequestFromArgs(args, setting_name):
   """Returns the get_request from the user-specified arguments.
 
@@ -70,6 +97,30 @@ def GetGetValueRequestFromArgs(args, setting_name):
   return get_request
 
 
+def GetLookupEffectiveValueRequestFromArgs(args, parent_resource):
+  """Returns the get_request from the user-specified arguments.
+
+  Args:
+    args: argparse.Namespace, An object that contains the values for the
+      arguments specified in the Args method.
+    parent_resource: resource location such as `organizations/123`
+  """
+
+  messages = settings_service.ResourceSettingsMessages()
+
+  if args.organization:
+    get_request = messages.ResourcesettingsOrganizationsSettingsValueLookupEffectiveValueRequest(
+        name=parent_resource)
+  elif args.folder:
+    get_request = messages.ResourcesettingsFoldersSettingsValueLookupEffectiveValueRequest(
+        name=parent_resource)
+  else:
+    get_request = messages.ResourcesettingsProjectsSettingsValueLookupEffectiveValueRequest(
+        name=parent_resource)
+
+  return get_request
+
+
 def GetListRequestFromArgs(args, parent_resource):
   """Returns the get_request from the user-specified arguments.
 
@@ -136,6 +187,31 @@ def GetServiceFromArgs(args):
   return service
 
 
+def GetUpdateValueRequestFromArgs(args, setting_value):
+  """Returns the get_request from the user-specified arguments.
+
+  Args:
+    args: argparse.Namespace, An object that contains the values for the
+      arguments specified in the Args method.
+    setting_value: setting value object contains name, value
+  """
+
+  messages = settings_service.ResourceSettingsMessages()
+
+  if args.organization:
+    message_type = messages.ResourcesettingsOrganizationsSettingsUpdateValueRequest
+  elif args.folder:
+    message_type = messages.ResourcesettingsFoldersSettingsUpdateValueRequest
+  else:
+    message_type = messages.ResourcesettingsProjectsSettingsUpdateValueRequest
+
+  get_request = message_type(name=setting_value.name,
+                             googleCloudResourcesettingsV1SettingValue
+                             =setting_value)
+
+  return get_request
+
+
 def GetValueServiceFromArgs(args):
   """Returns the value-service from the user-specified arguments.
 
