@@ -22,7 +22,7 @@ from googlecloudsdk.calliope import arg_parsers
 
 
 def AddFlexibleCacheStepOne(parser, resource_name, update_command=False):
-  """Adds cache mode, max ttl, default ttl, client ttl, negative caching, negative caching policy and custom response header  args to the argparse."""
+  """Adds cache mode, max ttl, default ttl, client ttl and custom response header args to the argparse."""
   # TODO (b/165456063) document enums as lowercase-with-dash. Accept both forms.
   parser.add_argument(
       '--cache-mode',
@@ -62,13 +62,12 @@ def AddFlexibleCacheStepOne(parser, resource_name, update_command=False):
   The value of clientTtl cannot be set to a value greater than that of maxTtl,
   but can be equal.
 
-  Any cacheable response has its max-age/s-maxage directives and/or
-  Expires header adjusted down to the client TTL value if necessary.
+  Any cacheable response has its max-age/s-maxage directives adjusted down to
+  the client TTL value if necessary; an Expires header will be replaced with a
+  suitable max-age directive.
 
   The maximum allowed value is 86400s (1 day).
 
-  Omit this field to use the value of defaultTtl as the clientTtl.
-
   When creating a new backend with CACHE_ALL_STATIC and the field is unset, or
   when switching to that mode and the field is unset, a default value of 3600
   is used.
@@ -87,7 +86,7 @@ def AddFlexibleCacheStepOne(parser, resource_name, update_command=False):
         '--no-client-ttl', action='store_true', help='Clears client TTL value.')
   default_ttl_help = """\
   Specifies the default TTL for cached content served by this origin for
-  responses that do not have an existing valid TTL (max-age or s-max-age).
+  responses that do not have an existing valid TTL (max-age or s-maxage).
 
   The default value is 3600s for cache modes that allow a default TTL to be
   defined.
@@ -150,78 +149,6 @@ def AddFlexibleCacheStepOne(parser, resource_name, update_command=False):
   if update_command:
     max_ttl_group.add_argument(
         '--no-max-ttl', action='store_true', help='Clears max TTL value.')
-  negative_caching_help = """\
-  Negative caching allows per-status code cache TTLs to be set, in order to
-  apply fine-grained caching for common errors or redirects. This can reduce
-  the load on your origin and improve the end-user experience by reducing response
-  latency.
-
-  Negative caching applies to 3xx, 4xx, and 5xx status codes that are cacheable
-  by default.
-
-  Status codes not listed here cannot have their TTL explicitly set and aren't
-  cached, in order to avoid cache poisoning attacks.
-
-  HTTP success codes (HTTP 2xx) are handled by the values of defaultTtl and
-  maxTtl.
-
-  When the cache mode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, these
-  values apply to responses with the specified response code that lack any
-  `cache-control`, `expires`, or `pragma: no-cache` headers.
-
-  When the cache mode is set to FORCE_CACHE_ALL, these values apply to all
-  responses with the specified response code, and override any caching headers.
-
-  By default, Cloud CDN applies the following default TTLs to these status
-  codes:
-  - HTTP 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m
-  - HTTP 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s
-  - HTTP 405 (Method Not Found), 414 (URI Too Long), 421 (Misdirected Request),
-    501 (Not Implemented): 60s
-
-  These defaults can be overridden in cdnPolicy.negativeCachingPolicy
-  """
-  negative_caching_group = parser.add_mutually_exclusive_group()
-  if update_command:
-    negative_caching_group.add_argument(
-        '--negative-caching',
-        action=arg_parsers.StoreTrueFalseAction,
-        help=negative_caching_help)
-  else:
-    parser.add_argument(
-        '--negative-caching',
-        action=arg_parsers.StoreTrueFalseAction,
-        help=negative_caching_help)
-  negative_caching_policy_help = """\
-  Sets a cache TTL for the specified HTTP status code.
-
-  NegativeCaching must be enabled to config the negativeCachingPolicy.
-
-  If you omit the policy and leave negativeCaching enabled, Cloud CDN's default
-  cache TTLs are used.
-
-  Note that when specifying an explicit negative caching policy, make sure that
-  you specify a cache TTL for all response codes that you want to cache. Cloud
-  CDN doesn't apply any default negative caching when a policy exists.
-
-  *CODE* is the HTTP status code to define a TTL against. Only HTTP status codes
-  300, 301, 308, 404, 405, 410, 414, 421, 451, and 501 can be specified as
-  values, and you cannot specify a status code more than once.
-
-  TTL is the time to live (in seconds) for which to cache responses for the
-  specified *CODE*. The maximum allowed value is 1800s (30 minutes), noting that
-  infrequently accessed objects may be evicted from the cache before the defined TTL.
-  """
-  negative_caching_group.add_argument(
-      '--negative-caching-policy',
-      type=arg_parsers.ArgDict(key_type=int, value_type=int),
-      metavar='[CODE=TTL]',
-      help=negative_caching_policy_help)
-  if update_command:
-    negative_caching_group.add_argument(
-        '--no-negative-caching-policies',
-        action='store_true',
-        help='Remove all negative caching policies for the %s.' % resource_name)
   custom_response_header_help = """\
   Custom headers that the external HTTP(S) load balancer adds to proxied responses.
   For the list of headers, see [Creating custom headers](https://cloud.google.com/load-balancing/docs/custom-headers).
@@ -238,3 +165,141 @@ def AddFlexibleCacheStepOne(parser, resource_name, update_command=False):
         '--no-custom-response-headers',
         action='store_true',
         help='Remove all custom response headers for the %s.' % resource_name)
+
+
+def AddNegativeCache(parser, resource_name, update_command=False):
+  """Adds negative caching and negative caching policy args to the argparse."""
+  negative_caching_help = """\
+    Negative caching allows per-status code cache TTLs to be set, in order to
+    apply fine-grained caching for common errors or redirects. This can reduce
+    the load on your origin and improve the end-user experience by reducing response
+    latency.
+
+    Negative caching applies to a set of 3xx, 4xx, and 5xx status codes that are
+    typically useful to cache.
+
+    Status codes not listed here cannot have their TTL explicitly set and aren't
+    cached, in order to avoid cache poisoning attacks.
+
+    HTTP success codes (HTTP 2xx) are handled by the values of defaultTtl and
+    maxTtl.
+
+    When the cache mode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, these
+    values apply to responses with the specified response code that lack any
+    `cache-control` or `expires` headers.
+
+    When the cache mode is set to FORCE_CACHE_ALL, these values apply to all
+    responses with the specified response code, and override any caching headers.
+
+    Cloud CDN applies the following default TTLs to these status codes:
+    - HTTP 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m
+    - HTTP 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s
+    - HTTP 405 (Method Not Found), 421 (Misdirected Request),
+      501 (Not Implemented): 60s
+
+    These defaults can be overridden in cdnPolicy.negativeCachingPolicy
+    """
+  negative_caching_group = parser.add_mutually_exclusive_group()
+  if update_command:
+    negative_caching_group.add_argument(
+        '--negative-caching',
+        action=arg_parsers.StoreTrueFalseAction,
+        help=negative_caching_help)
+  else:
+    parser.add_argument(
+        '--negative-caching',
+        action=arg_parsers.StoreTrueFalseAction,
+        help=negative_caching_help)
+  negative_caching_policy_help = """\
+    Sets a cache TTL for the specified HTTP status code.
+
+    NegativeCaching must be enabled to config the negativeCachingPolicy.
+
+    If you omit the policy and leave negativeCaching enabled, Cloud CDN's default
+    cache TTLs are used.
+
+    Note that when specifying an explicit negative caching policy, make sure that
+    you specify a cache TTL for all response codes that you want to cache. Cloud
+    CDN doesn't apply any default negative caching when a policy exists.
+
+    *CODE* is the HTTP status code to define a TTL against. Only HTTP status codes
+    300, 301, 308, 404, 405, 410, 421, 451, and 501 can be specified as values,
+    and you cannot specify a status code more than once.
+
+    TTL is the time to live (in seconds) for which to cache responses for the
+    specified *CODE*. The maximum allowed value is 1800s (30 minutes), noting that
+    infrequently accessed objects may be evicted from the cache before the defined TTL.
+    """
+  negative_caching_group.add_argument(
+      '--negative-caching-policy',
+      type=arg_parsers.ArgDict(key_type=int, value_type=int),
+      metavar='[CODE=TTL]',
+      help=negative_caching_policy_help)
+  if update_command:
+    negative_caching_group.add_argument(
+        '--no-negative-caching-policies',
+        action='store_true',
+        help='Remove all negative caching policies for the %s.' % resource_name)
+
+
+def AddFlexibleCacheStepTwo(parser, resource_name, update_command=False):
+  """Adds serve-while-stale and bypass-cache-on-request-headers args to the argparse."""
+  serve_while_stale_help = """\
+  Serve existing content from the cache (if available) when revalidating
+  content with the origin; this allows content to be served more quickly, and
+  also allows content to continue to be served if the backend is down or
+  reporting errors.
+
+  This setting defines the default serve-stale duration for any cached responses
+  that do not specify a stale-while-revalidate directive. Stale responses that
+  exceed the TTL configured here will not be served without first being
+  revalidated with the origin. The default limit is 86400s (1 day), which will
+  allow stale content to be served up to this limit beyond the max-age
+  (or s-max-age) of a cached response.
+
+  The maximum allowed value is 604800 (1 week).
+
+  Set this to zero (0) to disable serve-while-stale.
+  """
+  serve_while_stale_group = parser.add_mutually_exclusive_group()
+  serve_while_stale_group.add_argument(
+      '--serve-while-stale',
+      type=arg_parsers.Duration(upper_bound=604800),
+      default=None,
+      help=serve_while_stale_help,
+  )
+  if update_command:
+    serve_while_stale_group.add_argument(
+        '--no-serve-while-stale',
+        action='store_true',
+        help='Clears serve while stale value.')
+  bypass_cache_on_request_headers_help = """\
+  Bypass the cache when the specified request headers are matched - e.g.
+  Pragma or Authorization headers. Up to 5 headers can be specified.
+
+  The cache is bypassed for all cdnPolicy.cacheMode settings.
+
+  Note that requests that include these headers will always fill from origin,
+  and may result in a large number of cache misses if the specified headers are
+  common to many requests.
+
+  Values are case-insensitive.
+
+  The header name must be a valid HTTP header field token (per RFC 7230).
+
+  For the list of restricted headers, see the list of required header name
+  properties in [How custom headers work](https://cloud.google.com/load-balancing/docs/custom-headers#how_custom_headers_work).
+
+  A header name must not appear more than once in the list of added headers.
+  """
+  bypass_cache_on_request_headers_group = parser.add_mutually_exclusive_group()
+  bypass_cache_on_request_headers_group.add_argument(
+      '--bypass-cache-on-request-headers',
+      action='append',
+      help=bypass_cache_on_request_headers_help)
+  if update_command:
+    bypass_cache_on_request_headers_group.add_argument(
+        '--no-bypass-cache-on-request-headers',
+        action='store_true',
+        help='Remove all bypass cache on request headers for the %s.' %
+        resource_name)
