@@ -37,8 +37,8 @@ _DETAILED_SOURCE_SNAPSHOT_HELP = """\
       size of the disks.
 """
 
-_DETAILED_SOURCE_IN_PLACE_SNAPSHOT_HELP = """\
-      Source in place snapshot used to create the disks.
+_DETAILED_SOURCE_INSTANT_SNAPSHOT_HELP = """\
+      Source instant snapshot used to create the disks.
 """
 
 _SOURCE_DISK_DETAILED_HELP = """\
@@ -112,10 +112,28 @@ def AddMultiWriterFlag(parser):
   return parser.add_argument(
       '--multi-writer',
       action='store_true',
-      help=('Create the disk in multi-writer mode so that it can be attached '
-            'with read-write access to multiple VMs. Cannot be used with '
-            'regional disks. Multi-writer disk does not yet support resize and '
-            'snapshot operations.'))
+      help="""
+      Create the disk in multi-writer mode so that it can be attached
+      with read-write access to multiple VMs. Can only be used with
+      zonal SSD persistent disks. Disks in multi-writer mode do not support
+      resize and snapshot operations.
+      """)
+
+
+def AddProvisionedIopsFlag(parser, arg_parsers, constants):
+  return parser.add_argument(
+      '--provisioned-iops',
+      type=arg_parsers.BoundedInt(constants.MIN_PROVISIONED_IOPS,
+                                  constants.MAX_PROVISIONED_IOPS),
+      help=(
+          'Provisioned IOPS of pd-extreme disk to create. Only for use with '
+          'disks of type pd-extreme. If specified, the value must be in the '
+          'range between {min} and {max}. If not specified, the default value '
+          'is {default}.').format(
+              min=constants.MIN_PROVISIONED_IOPS,
+              max=constants.MAX_PROVISIONED_IOPS,
+              default=constants.DEFAULT_PROVISIONED_IOPS))
+
 
 SOURCE_SNAPSHOT_ARG = compute_flags.ResourceArgument(
     resource_name='snapshot',
@@ -127,16 +145,16 @@ SOURCE_SNAPSHOT_ARG = compute_flags.ResourceArgument(
     short_help='Source snapshot used to create the disks.',
     detailed_help=_DETAILED_SOURCE_SNAPSHOT_HELP,)
 
-SOURCE_IN_PLACE_SNAPSHOT_ARG = compute_flags.ResourceArgument(
-    resource_name='source in place snapshot',
-    completer=compute_completers.InPlaceSnapshotsCompleter,
-    name='--source-in-place-snapshot',
-    zonal_collection='compute.zoneInPlaceSnapshots',
-    regional_collection='compute.regionInPlaceSnapshots',
+SOURCE_INSTANT_SNAPSHOT_ARG = compute_flags.ResourceArgument(
+    resource_name='source instant snapshot',
+    completer=compute_completers.InstantSnapshotsCompleter,
+    name='--source-instant-snapshot',
+    zonal_collection='compute.zoneInstantSnapshots',
+    regional_collection='compute.regionInstantSnapshots',
     plural=False,
     required=False,
-    short_help='Source in place snapshot used to create the disks.',
-    detailed_help=_DETAILED_SOURCE_IN_PLACE_SNAPSHOT_HELP,
+    short_help='Source instant snapshot used to create the disks.',
+    detailed_help=_DETAILED_SOURCE_INSTANT_SNAPSHOT_HELP,
     use_existing_default_scope=True)
 
 SOURCE_DISK_ARG = compute_flags.ResourceArgument(
