@@ -283,7 +283,7 @@ class ConsoleAttr(object):
 
     # Encoded character attributes.
     is_screen_reader = properties.VALUES.accessibility.screen_reader.GetBool()
-    if self._encoding == 'utf8' and not is_screen_reader:
+    if self._encoding == 'utf-8' and not is_screen_reader:
       self._box_line_characters = BoxLineCharactersUnicode()
       self._bullets = self._BULLETS_UNICODE
       self._progress_tracker_symbols = ProgressTrackerSymbolsUnicode()
@@ -321,7 +321,7 @@ class ConsoleAttr(object):
       locale_encoding = locale.getpreferredencoding()
       if locale_encoding and 'cp1252' in locale_encoding:
         return None
-      return 'utf8'
+      return 'utf-8'
     elif 'cp437' in console_encoding:
       return 'cp437'
     elif 'cp1252' in console_encoding:
@@ -348,7 +348,6 @@ class ConsoleAttr(object):
           color_code=self._ANSI_COLOR[color],
           reset_code=self._ANSI_COLOR_RESET,
           string=string)
-    # TODO(b/35939231): Add elif self._encoding == 'cp437': code here.
     return string
 
   def ConvertOutputToUnicode(self, buf):
@@ -583,6 +582,13 @@ class ConsoleAttr(object):
     return lines
 
   def SupportsAnsi(self):
+    """Indicates whether the terminal appears to support ANSI escape sequences.
+
+    Returns:
+      bool: True if ANSI seems to be supported; False otherwise.
+    """
+    if console_attr_os.ForceEnableAnsi():
+      return True
     return (self._encoding != 'ascii' and
             ('screen' in self._term or 'xterm' in self._term))
 
