@@ -24,7 +24,8 @@ from googlecloudsdk.command_lib.artifacts import settings_util
 from googlecloudsdk.core import log
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 class Maven(base.Command):
   """Print a snippet to add a Maven repository to the pom.xml file."""
 
@@ -41,12 +42,17 @@ class Maven(base.Command):
     To print a snippet for repository `my-repository` in the default location:
 
       $ {command} --repository="my-repository"
+
+    To print a snippet using service account key:
+
+      $ {command} --json-key=path/to/key.json
     """,
   }
 
   @staticmethod
   def Args(parser):
     flags.GetRepoFlag().AddToParser(parser)
+    flags.GetJsonKeyFlag("maven").AddToParser(parser)
     parser.display_info.AddFormat("value(mvn)")
 
   def Run(self, args):
@@ -62,4 +68,3 @@ class Maven(base.Command):
 
     log.status.Print("Note: Language package support is in Alpha.\n")
     return {"mvn": settings_util.GetMavenSnippet(args)}
-
