@@ -65,6 +65,8 @@ class UpdateBeta(base.UpdateCommand):
       Some value that we want to have printed later.
     """
 
+    wp_region = args.region
+
     release_track = self.ReleaseTrack()
     client = cloudbuild_util.GetClientInstance(release_track)
     messages = cloudbuild_util.GetMessagesModule(release_track)
@@ -73,7 +75,6 @@ class UpdateBeta(base.UpdateCommand):
 
     # Get the workerpool proto from either the flags or the specified file.
     wp = messages.WorkerPool()
-    wp_region = args.region
     if args.config_from_file is not None:
       wp = workerpool_config.LoadWorkerpoolConfigFromPath(
           args.config_from_file, messages)
@@ -89,6 +90,8 @@ class UpdateBeta(base.UpdateCommand):
       if args.worker_disk_size is not None:
         worker_config.diskSizeGb = compute_utils.BytesToGb(
             args.worker_disk_size)
+      if args.no_external_ip:
+        worker_config.noExternalIp = True
       wp.workerConfig = worker_config
 
     # Get the workerpool ref
@@ -117,7 +120,8 @@ class UpdateBeta(base.UpdateCommand):
 
     # Format the workerpool name for display
     try:
-      updated_wp.name = cloudbuild_util.WorkerPoolShortName(updated_wp.name)
+      updated_wp.name = cloudbuild_util.RegionalWorkerPoolShortName(
+          updated_wp.name)
     except ValueError:
       pass  # Must be an old version.
 
@@ -125,92 +129,8 @@ class UpdateBeta(base.UpdateCommand):
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class UpdateAlpha(base.UpdateCommand):
+class UpdateAlpha(UpdateBeta):
   """Update a workerpool used by Google Cloud Build.
 
   Update a worker pool used by Google Cloud Build.
   """
-
-  @staticmethod
-  def Args(parser):
-    """Register flags for this command.
-
-    Args:
-      parser: An argparse.ArgumentParser-like object. It is mocked out in order
-        to capture some information, but behaves like an ArgumentParser.
-    """
-    parser = workerpool_flags.AddWorkerpoolUpdateArgs(
-        parser, release_track=base.ReleaseTrack.ALPHA)
-    parser.display_info.AddFormat("""
-          table(
-            name,
-            createTime.date('%Y-%m-%dT%H:%M:%S%Oz', undefined='-'),
-            state
-          )
-        """)
-
-  def Run(self, args):
-    """This is what gets called when the user runs this command.
-
-    Args:
-      args: an argparse namespace. All the arguments that were provided to this
-        command invocation.
-
-    Returns:
-      Some value that we want to have printed later.
-    """
-
-    release_track = self.ReleaseTrack()
-    client = cloudbuild_util.GetClientInstance(release_track)
-    messages = cloudbuild_util.GetMessagesModule(release_track)
-
-    parent = properties.VALUES.core.project.Get(required=True)
-
-    # Get the workerpool proto from either the flags or the specified file.
-    wp = messages.WorkerPool()
-    if args.config_from_file is not None:
-      wp = workerpool_config.LoadWorkerpoolConfigFromPath(
-          args.config_from_file, messages)
-    else:
-      wp.name = args.WORKER_POOL
-      if args.region is not None:
-        wp.region = args.region
-      if args.peered_network is not None:
-        network_config = messages.NetworkConfig()
-        network_config.peeredNetwork = args.peered_network
-        wp.networkConfig = network_config
-      worker_config = messages.WorkerConfig()
-      if args.worker_machine_type is not None:
-        worker_config.machineType = args.worker_machine_type
-      if args.worker_disk_size is not None:
-        worker_config.diskSizeGb = compute_utils.BytesToGb(
-            args.worker_disk_size)
-      wp.workerConfig = worker_config
-
-    # Get the workerpool ref
-    wp_resource = resources.REGISTRY.Parse(
-        None,
-        collection='cloudbuild.projects.workerPools',
-        api_version=cloudbuild_util.RELEASE_TRACK_TO_API_VERSION[release_track],
-        params={
-            'projectsId': parent,
-            'workerPoolsId': wp.name,
-        })
-
-    update_mask = cloudbuild_util.MessageToFieldPaths(wp)
-    req = messages.CloudbuildProjectsWorkerPoolsPatchRequest(
-        name=wp_resource.RelativeName(),
-        workerPool=wp,
-        updateMask=','.join(update_mask))
-    # Send the Update request
-    updated_wp = client.projects_workerPools.Patch(req)
-
-    log.UpdatedResource(wp_resource)
-
-    # Format the workerpool name for display
-    try:
-      updated_wp.name = cloudbuild_util.WorkerPoolShortName(updated_wp.name)
-    except ValueError:
-      pass  # Must be an old version.
-
-    return updated_wp
