@@ -55,11 +55,12 @@ class MySQL(base.Command):
           on the command line after this command. Positional arguments are
           allowed.
     """
-    resource_args.AddMigrationJobResourceArgs(parser, 'to create')
+    resource_args.AddMigrationJobResourceArgs(
+        parser, 'to create', required=True)
     mj_flags.AddDisplayNameFlag(parser)
-    mj_flags.AddTypeFlag(parser)
+    mj_flags.AddTypeFlag(parser, required=True)
     mj_flags.AddDumpPathFlag(parser)
-    mj_flags.AddConnectivityGroupFlag(parser)
+    mj_flags.AddConnectivityGroupFlag(parser, required=True)
     flags.AddLabelsCreateFlags(parser)
 
   def Run(self, args):
@@ -79,7 +80,7 @@ class MySQL(base.Command):
     source_ref = args.CONCEPTS.source.Parse()
     destination_ref = args.CONCEPTS.destination.Parse()
 
-    cp_client = migration_jobs.MigrationJobsClient()
+    cp_client = migration_jobs.MigrationJobsClient(self.ReleaseTrack())
     result_operation = cp_client.Create(
         parent_ref,
         migration_job_ref.migrationJobsId,
@@ -87,9 +88,9 @@ class MySQL(base.Command):
         destination_ref,
         args)
 
-    client = api_util.GetClientInstance()
-    messages = api_util.GetMessagesModule()
-    resource_parser = api_util.GetResourceParser()
+    client = api_util.GetClientInstance(self.ReleaseTrack())
+    messages = api_util.GetMessagesModule(self.ReleaseTrack())
+    resource_parser = api_util.GetResourceParser(self.ReleaseTrack())
 
     operation_ref = resource_parser.Create(
         'datamigration.projects.locations.operations',
