@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,8 +14,11 @@
 # limitations under the License.
 
 """Triggers execution of a Google Cloud Function."""
+
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 import json
 
 from googlecloudsdk.api_lib.functions import util
@@ -31,11 +34,17 @@ class Call(base.Command):
 
   ## EXAMPLES
 
-  To call a function giving it hello world in message field of its event
+  To call a function, giving it 'Hello World!' in the message field of its event
   argument (depending on your environment you might need to escape
-  characters in --data flag value differently):
+  characters in `--data` flag value differently), run:
 
-      $ {command} helloWorld --data '{"message": "Hello World!"}'
+      $ {command} helloWorld --data='{"message": "Hello World!"}'
+
+  Note that this method has a limited quota which cannot be increased. It is
+  intended for testing and debugging and should not be used in production.
+
+  Calls to HTTP-triggered functions are sent as HTTP POST requests. To use other
+  HTTP methods, use a dedicated HTTP request tool such as cURL or wget.
 
   """
 
