@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+import textwrap
+
 from googlecloudsdk.api_lib.iam import util
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.iam import iam_util
@@ -30,13 +32,27 @@ from googlecloudsdk.core.console import console_io
 class Delete(base.Command):
   """Delete a user-managed key from a service account."""
 
+  detailed_help = {
+      'EXAMPLES': textwrap.dedent("""
+          To delete a key with ID `b4f1037aeef9ab37deee9` for the service
+          account `my-iam-account@example.com`, run:
+
+            $ {command} b4f1037aeef9ab37deee9 --iam-account=my-iam-account@example.com
+      """),
+  }
+
   @staticmethod
   def Args(parser):
     parser.add_argument('--iam-account',
                         required=True,
                         type=iam_util.GetIamAccountFormatValidator(),
-                        help='The service account whose key to '
-                        'delete.')
+                        help="""\
+                          The service account from which to delete a key.
+
+                          To list all service accounts in the project, run:
+
+                            $ gcloud iam service-accounts list
+                        """)
 
     parser.add_argument('key',
                         metavar='KEY-ID',
