@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,8 +16,11 @@
 """Command for signing jwts for service accounts."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
 
+import textwrap
+
 from googlecloudsdk.api_lib.iam import util
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.iam import iam_util
@@ -30,19 +33,23 @@ class SignJwt(base.Command):
   """Sign a JWT with a managed service account key.
 
   This command signs a JWT using a system-managed service account key.
-
-  ## EXAMPLES:
-  To create a sign JWT with a system-managed service account key,
-  run:
-
-    $ {command} --iam-account my-account@somedomain.com input.json output.jwt
-
-  ## SEE ALSO:
-  For more information on how this command ties into the wider cloud
-  infrastructure, please see
-  [](https://cloud.google.com/appengine/docs/java/appidentity/).
   """
 
+  detailed_help = {
+      'EXAMPLES':
+          textwrap.dedent("""
+          To create a sign JWT with a system-managed service account key, run:
+
+            $ {command} --iam-account=my-account@example.com input.json output.jwt
+          """),
+      'SEE ALSO':
+          textwrap.dedent("""
+          For more information on how this command ties into the wider cloud
+          infrastructure, please see
+          [](https://cloud.google.com/appengine/docs/java/appidentity/).
+        """),
+  }
+
   @staticmethod
   def Args(parser):
     parser.add_argument(
@@ -69,7 +76,7 @@ class SignJwt(base.Command):
                 payload=files.ReadFileContents(args.input,))))
 
     log.WriteToFileOrStdout(
-        args.output, content=response.signedJwt, binary=True)
+        args.output, content=response.signedJwt, binary=False, private=True)
     log.status.Print(
         'signed jwt [{0}] as [{1}] for [{2}] using key [{3}]'.format(
             args.input, args.output, args.iam_account, response.keyId))
