@@ -20,7 +20,6 @@ from __future__ import unicode_literals
 
 import json
 
-from googlecloudsdk.api_lib.kuberun import service
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.kuberun import flags
 from googlecloudsdk.command_lib.kuberun import kuberun_command
@@ -30,9 +29,15 @@ from googlecloudsdk.core.resource import resource_printer
 _DETAILED_HELP = {
     'EXAMPLES':
         """
-        To show all the data about a KubeRun service, run:
+        To show all the data about a KubeRun service in the default namespace,
+        run:
 
             $ {command} SERVICE
+
+        To show all the data about a KubeRun service in a specific namespace
+        ``NAMESPACE'', run:
+
+            $ {command} SERVICE --namespace=NAMESPACE
         """,
 }
 
@@ -62,4 +67,4 @@ class Describe(kuberun_command.KubeRunCommand, base.DescribeCommand):
     return ['core', 'services', 'describe']
 
   def FormatOutput(self, out, args):
-    return service.Service(json.loads(out))
+    return json.loads(out)
